@@ -1,13 +1,13 @@
 /**********************************************************************
- * $Id: cpl_time.h 34518 2016-07-02 21:01:34Z goatbar $
+ * $Id$
  *
  * Name:     cpl_time.h
  * Project:  CPL - Common Portability Library
  * Purpose:  Time functions.
- * Author:   Even Rouault, <even dot rouault at mines dash paris dot org>
+ * Author:   Even Rouault, <even dot rouault at spatialys.com>
  *
  **********************************************************************
- * Copyright (c) 2009, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2009, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -35,7 +35,11 @@
 
 #include "cpl_port.h"
 
-struct tm CPL_DLL * CPLUnixTimeToYMDHMS(GIntBig unixTime, struct tm* pRet);
+struct tm CPL_DLL *CPLUnixTimeToYMDHMS(GIntBig unixTime, struct tm *pRet);
 GIntBig CPL_DLL CPLYMDHMSToUnixTime(const struct tm *brokendowntime);
 
-#endif // CPL_TIME_H_INCLUDED
+int CPL_DLL CPLParseRFC822DateTime(const char *pszRFC822DateTime, int *pnYear,
+                                   int *pnMonth, int *pnDay, int *pnHour,
+                                   int *pnMinute, int *pnSecond, int *pnTZFlag,
+                                   int *pnWeekDay);
+#endif  // CPL_TIME_H_INCLUDED
